@@ -14,8 +14,13 @@ from twisted.internet.defer import DeferredSemaphore
 from twisted.internet.defer import inlineCallbacks
 from vortex.Tuple import Tuple
 
+from attune_project_api.items.step_tuples.step_sql_oracle_tuple import (
+    StepSqlOracleTuple,
+)
+from attune_project_api.migration import runMigrationsForStorageContext
 from .git_lib_mixin import GitLibMixin
 from ..Exceptions import ItemNotFoundError
+from ..Exceptions import ProjectValidationError
 from ..ObjectStorageContext import ContextProjectInfo
 from ..ObjectStorageContext import ObjectStorageContext
 from ..ObjectStorageContext import ObjectStorageContextFileMixin
@@ -35,14 +40,6 @@ logger = logging.getLogger(__name__)
 DIR_CREATE_MODE = 0o700
 
 
-class ProjectValidationError(Exception):
-    def __init__(self, errors: list[str]):
-        Exception.__init__(
-            self, "%s errors occurred during load of project" % len(errors)
-        )
-        self.errors: list[str] = errors
-
-
 class GitObjectStorageContextFileMixin(ObjectStorageContextFileMixin):
     CONTENTS_PATH = "contents"
 
@@ -276,6 +273,12 @@ class GitObjectStorageContext(
         self.__instanceByKeyByGroup[ItemStorageGroupEnum.FileArchive] = {}
 
     def load(self):
+        # Run the migrations to bring the project to the latest revision
+        # Migrations need to be run before the items are loaded and as a
+        # result cannot use the public methods (getItem, addItem) in the
+        # `upgrade` and `downgrade` functions
+        runMigrationsForStorageContext(self)
+
         # Cache all items in memory upon load.
         # This will speed up the access of the data
         self.__loadItems(ItemStorageGroupEnum.Parameter)
@@ -286,6 +289,18 @@ class GitObjectStorageContext(
     def project(self) -> ContextProjectInfo:
         return self.__projectInfo
 
+    def getRevision(self) -> str:
+        metadata = self.metadata
+        # If revision is missing return the first revision
+        return metadata.get("revision", "16e34a42a9a1")
+
+    def setRevision(self, revision: str):
+        metadata = self.metadata
+        metadata["revision"] = revision
+
+        self.writeMetadata(metadata)
+        self.commit("Wrote metadata.json")
+
     def getItem(
         self, group: ItemStorageGroupEnum, key: str
     ) -> Optional[StorageTuple]:
@@ -464,7 +479,8 @@ class GitObjectStorageContext(
     def __writeItem(self, item: type[StorageTuple]) -> None:
         fields = item.tupleToRestfulJsonDict()
         comment = fields.pop("comment", None)
-        script = fields.pop("script", None)
+        # Scripts and SQL is stored under a `script.txt` file
+        script = fields.pop("script", None) or fields.pop("sql", None)
 
         # FIXME If the name isn't suitable for storage
         #  then an exception needs raising instead.
@@ -483,9 +499,13 @@ class GitObjectStorageContext(
         )
 
         if comment:
-            self._writeFile((itemPath / "comment.md").as_posix(), comment.encode())
+            self._writeFile(
+                (itemPath / "comment.md").as_posix(), comment.encode()
+            )
         if script:
-            self._writeFile((itemPath / "script.txt").as_posix(), script.encode())
+            self._writeFile(
+                (itemPath / "script.txt").as_posix(), script.encode()
+            )
 
     def __moveItemDirectory(
         self, group: ItemStorageGroupEnum, oldKey: str, newKey: str
@@ -545,9 +565,13 @@ class GitObjectStorageContext(
 
         try:
             scriptData = self._readFile(path / "script.txt")
-            # Not every item has target 'script' associated with it
+            # Not every item has target 'script' or `sql` associated with it
             if scriptData is not None:
-                metadata["script"] = scriptData.decode()
+                metadata[
+                    "sql"
+                    if metadata["type"] == StepSqlOracleTuple.tupleType()
+                    else "script"
+                ] = scriptData.decode()
         except FileNotFoundError:
             pass
 
