@@ -151,11 +151,19 @@ class GitLibMixin:
         else:
             cred = pygit2.UserPass(username, password)
 
+        class RemoteCallback(RemoteCallbacks):
+            def credentials(self, url, username_from_url, allowed_types):
+                return cred
+
+            def certificate_check(self, certificate, valid, host):
+                # Return whatever the TLS/SSH library thinks about the cert
+                return valid
+
         pygit2.clone_repository(
             url,
             projectPath.as_posix(),
             bare=False,
-            callbacks=RemoteCallbacks(credentials=cred),
+            callbacks=RemoteCallback(),
         )
 
     def _writeFile(self, path: str, data: bytes, mode=pygit2.GIT_FILEMODE_BLOB):
@@ -507,9 +515,17 @@ class GitLibMixin:
 
         remote = self.__repo.remotes[remote]
 
+        class RemoteCallback(RemoteCallbacks):
+            def credentials(self, url, username_from_url, allowed_types):
+                return cred
+
+            def certificate_check(self, certificate, valid, host):
+                # Return whatever the TLS/SSH library thinks about the cert
+                return valid
+
         remote.push(
             [self.__checkedOutBranch.name],
-            callbacks=pygit2.RemoteCallbacks(credentials=cred),
+            callbacks=RemoteCallback(),
         )
 
     def pullFromRemote(
@@ -524,7 +540,16 @@ class GitLibMixin:
             cred = pygit2.UserPass(username, password)
 
         remote = self.__repo.remotes[remoteName]
-        remote.fetch(callbacks=RemoteCallbacks(credentials=cred))
+
+        class RemoteCallback(RemoteCallbacks):
+            def credentials(self, url, username_from_url, allowed_types):
+                return cred
+
+            def certificate_check(self, certificate, valid, host):
+                # Return whatever the TLS/SSH library thinks about the cert
+                return valid
+
+        remote.fetch(callbacks=RemoteCallback())
 
         checkedOutBranch = self.__checkedOutBranch
         remoteBranchName = f"{remoteName}/{checkedOutBranch.shorthand}"
